@@ -984,7 +984,7 @@ static void vand2s(unsigned char * ansp, const int o,
   case STRSXP:
     if (TYPEOF(y) == STRSXP && (o == OP_EQ || o == OP_NE)) {
     // only support == and !=
-      vand2_SS(ansp, o, STRING_PTR(x), N, STRING_PTR(y), M);
+      vand2_SS(ansp, o, STRING_PTR_RO(x), N, STRING_PTR_RO(y), M);
     } else {
       *err = AND3_UNSUPPORTED_TYPEY;
     }
