@@ -1,5 +1,5 @@
 #include "hutilscpp.h"
 
 SEXP ScalarLength(R_xlen_t o) {
-  return (o < INT_MAX) ? ScalarInteger(o) : ScalarReal(o);
+  return (o <= INT_MAX) ? ScalarInteger(o) : ScalarReal(o);
 }
